#ifndef stracciatella_h
#define stracciatella_h

#include <cstdarg>
#include <cstdint>
#include <cstdlib>

enum class ScalingQuality {
  LINEAR,
  NEAR_PERFECT,
  PERFECT,
};

enum class VanillaVersion {
  DUTCH,
  ENGLISH,
  FRENCH,
  GERMAN,
  ITALIAN,
  POLISH,
  RUSSIAN,
  RUSSIAN_GOLD,
};

struct EngineOptions;

extern "C" {

EngineOptions *create_engine_options(const char *const *array, size_t length);

char *find_ja2_executable(const char *launcher_path_ptr);

void free_engine_options(EngineOptions *ptr);

void free_rust_string(char *s);

float get_brightness(const EngineOptions *ptr);

char *get_mod(const EngineOptions *ptr, uint32_t index);

uint32_t get_number_of_mods(const EngineOptions *ptr);

uint16_t get_resolution_x(const EngineOptions *ptr);

uint16_t get_resolution_y(const EngineOptions *ptr);

VanillaVersion get_resource_version(const EngineOptions *ptr);

char *get_resource_version_string(VanillaVersion version);

ScalingQuality get_scaling_quality(const EngineOptions *ptr);

char *get_scaling_quality_string(ScalingQuality quality);

char *get_stracciatella_home(const EngineOptions *ptr);

char *get_vanilla_data_dir(const EngineOptions *ptr);

void set_brightness(EngineOptions *ptr, float brightness);

void set_resolution(EngineOptions *ptr, uint16_t x, uint16_t y);

void set_resource_version(EngineOptions *ptr, VanillaVersion res);

void set_scaling_quality(EngineOptions *ptr, ScalingQuality scaling_quality);

void set_start_in_fullscreen(EngineOptions *ptr, bool val);

void set_start_without_sound(EngineOptions *ptr, bool val);

void set_vanilla_data_dir(EngineOptions *ptr, const char *data_dir_ptr);

bool should_run_editor(const EngineOptions *ptr);

bool should_run_unittests(const EngineOptions *ptr);

bool should_show_help(const EngineOptions *ptr);

bool should_start_in_debug_mode(const EngineOptions *ptr);

bool should_start_in_fullscreen(const EngineOptions *ptr);

bool should_start_in_window(const EngineOptions *ptr);

bool should_start_without_sound(const EngineOptions *ptr);

bool write_engine_options(EngineOptions *ptr);

} // extern "C"

#endif // stracciatella_h
